cheesecake.cheesecake_index.CheesecakeError

Package cheesecake :: Module cheesecake_index :: Class CheesecakeError |
[show private | hide private]
[frames | no frames]

## Class CheesecakeError

    Exception --+
                |
               CheesecakeError

Custom exception class for Cheesecake-specific errors.

Method Summary
Inherited from Exception
| ``__init__`(...)`
| ``__getitem__`(...)`
| ``__str__`(...)`

Generated by Epydoc 2.1 on Fri Feb 9 02:15:12 2007 | http://epydoc.sf.net